#include <zephyr/device.h>
#include <zephyr/devicetree.h>

#include "bme280.h"

#include <zephyr/logging/log.h>
LOG_MODULE_REGISTER(bme280);

const struct device *bme280;


#define CALIB_TEMP_VAL1 0
#define CALIB_PRES_VAL1 1
//#define CALIB_HUMI_VAL1 0

#define CALIB_TEMP_VAL2 0
#define CALIB_PRES_VAL2 500000
//#define CALIB_HUMI_VAL2 0

void init_bme280()
{
  bme280 = DEVICE_DT_GET_ANY(bosch_bme280);

  if (bme280 == NULL) {
    /* No such node, or the node does not have status "okay". */
     LOG_ERR("Error: no device found.\n");
     return;
  }

  if (!device_is_ready(bme280)) {
    LOG_ERR("Error: Device \"%s\" is not ready; ", bme280->name);
    return;
  }

  LOG_WRN("Found device \"%s\"", bme280->name);
}

void probe_bme280(bool ptemperature, bool phumidity, bool ppressure)
{
  if(ptemperature == true && ppressure == false)
  {
    sensor_sample_fetch_chan(bme280, SENSOR_CHAN_AMBIENT_TEMP);
  //} else if(phumidity == true && ppressure == false) {
  //  sensor_sample_fetch_chan(bme280, SENSOR_CHAN_HUMIDITY);
  } else {
    sensor_sample_fetch_chan(bme280, SENSOR_CHAN_ALL);
  }
}

struct sensor_value get_temperature()
{
    struct sensor_value sval;
    sensor_channel_get(bme280, SENSOR_CHAN_AMBIENT_TEMP, &sval);
    sval.val1 = sval.val1 + CALIB_TEMP_VAL1;
    sval.val2 = sval.val2 + CALIB_TEMP_VAL2;
    return sval;
}

struct sensor_value get_pressure()
{
    struct sensor_value sval;
    sensor_channel_get(bme280, SENSOR_CHAN_PRESS, &sval);
    sval.val1 = sval.val1 + CALIB_PRES_VAL1;
    sval.val2 = sval.val2 + CALIB_PRES_VAL2;
    return sval;
}

/* struct sensor_value get_humidity()
{
    struct sensor_value sval;
    sensor_channel_get(bme280, SENSOR_CHAN_HUMIDITY, &sval);
    sval.val1 = sval.val1 + CALIB_HUMI_VAL1;
    sval.val2 = sval.val2 + CALIB_HUMI_VAL2;
    return sval;
} */

